package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#`!4````!```````!]8@`````````0```````
M`0&H`````0!``#@`"`!``!T`'`````8````$`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````$0`````````1``````````$````!
M````!0```````````````````````````````````````+`D````````L"0`
M``````$```````$````&````````\Q@```````'S&````````?,8````````
M#6@````````=J````````0```````@````8```````#S2````````?-(````
M```!\T@````````"0`````````)```````````@````$````!`````````(4
M`````````A0````````"%`````````!$`````````$0`````````!&1TY5``
M```$````````J6P```````"I;````````*EL`````````0P````````!#```
M```````$9'3E4@````0```````#S&````````?,8```````!\Q@````````,
MZ`````````SH``````````$O;&EB-C0O;&0V-"YS;RXQ``````````0````4
M`````T=.50"::[?=DE3XZ9YLFO.P>JZN7?1(6`````0````0`````4=.50``
M`````````P````0`````````P0```&<`````````-````%P````J````````
M````````````,P``````````````,@```&(````<````&0```%4```!C````
M````````````````9````````````````````!0`````````````````````
M````````````````````````````````````````````````````````````
M```6`````````%``````````30`````````G````-0``````````````+P``
M```````D```````````````$````1P`````````````````````````]````
M`````#@```!.``````````D```````````````````!6````````````````
M````00````````!"````9@````````!&`````````````````````````%X`
M```&``````````P`````````0P`````````K`````````$0```!(````````
M`````````````````#D`````````,0```!````!E```````````````8````
M)@```````````````````$D````C````40````X````````````````````^
M`````P``````````````%P```%0`````````$P````````!8````/````#\`
M``````````````T```!?````&P````````!9````$0``````````````.P``
M`"X`````````.@`````````>````(`````@````%````2@```&``````````
M```````````+`````````%L````*````````````````````*````#<```!/
M````(@```"4```!7`````````"P``````````````%T```!`````````````
M``!3```````````````A`````````#``````````````````````````6@``
M`````````````````$4```!+````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````/````````
M``````!2````````````````````````````````````````````````````
M&@``````````````'0``````````````````````````````````````````
M```````````````````````````````?`````````!(`````````````````
M`````````````&$````M```````````````V````````````````````````
M`$P`````````````````````````````````````````*0``````````````
M````````````````%0`````````````````````````'`````````"X```!,
M````!`````B$!$`%`!`0((0`AH`$``(H"`0@"0``"8((`@"Z11"@B````$P`
M````````3@```%``````````40````````!2````4P````````!4````````
M`%4```!6`````````%@``````````````%D`````````6@``````````````
M`````%L```!<`````````%T```!>`````````%\``````````````&``````
M````80```&(```````````````````!C````9`````````!E``````````"V
MF\4N?)I_:PN7.@S,)8P5A]?Z0TG[X*/LU45#TW`'B1Q8<=F>X\W;FYRI?BU'
MWL\L/^7#?-1DU>W;8C.>XA0-"@*GX1_?Q6_60PEK#N3_(7R2X[O`XTNM;XL!
MLU">&FL!QD?C9LRO9F!LH?L`````````````````````````````````````
M``````,```P````````GP`````````````````,``!8```````'UB```````
M````````Y1(`````````````````````````````FQ(`````````````````
M````````````$!(````````````````````````````!3A(`````````````
M```````````````!:"`````````````````````````````!+Q(`````````
M```````````````````!*1(`````````````````````````````P!(`````
M```````````````````````!&Q(````````````````````````````!RA(`
M```````````````````````````"+!(`````````````````````````````
M;!(````````````````````````````";1(`````````````````````````
M```"JA(`````````````````````````````[!(`````````````````````
M````````6R$`````````````````````````````21(`````````````````
M```````````#"!$````````````````````````````"?!(`````````````
M```````````````!K1$`````````````````````````````>Q(`````````
M```````````````````"4!(````````````````````````````"`Q(`````
M```````````````````````"BA(`````````````````````````````9!(`
M````````````````````````````(A(````````````````````````````"
MM!(`````````````````````````````7!$`````````````````````````
M```#$Q(`````````````````````````````-!(`````````````````````
M````````/A(````````````````````````````!NA(`````````````````
M````````````A1(````````````````````````````!8A(`````````````
M```````````````!A"``````````````````````````````<Q(`````````
M```````````````````"QQ(````````````````````````````!#Q(`````
M`````````````````````````2(`````````````````````````````E!(`
M````````````````````````````6A$````````````````````````````#
M?Q(````````````````````````````"%1(`````````````````````````
M````HA(````````````````````````````"E1(`````````````````````
M```````!71(````````````````````````````"(1(`````````````````
M```````````"YQ(````````````````````````````!"!(`````````````
M````````````````\Q(````````````````````````````"^A(`````````
M````````````````````SQ(````````````````````````````"KQ(`````
M```````````````````````!YA(`````````````````````````````WA(`
M````````````````````````````^A(````````````````````````````"
M11(````````````````````````````!0!(`````````````````````````
M```"UA(`````````````````````````````CA(`````````````````````
M```````!V!(````````````````````````````!\A(`````````````````
M````````````L!(`````````````````````````````QQ(`````````````
M```````````````"7A(````````````````````````````"/!(`````````
M```````````````````!(A$`````````````````````````````UQ(`````
M````````````````````````MQ(````````````````````````````!51(`
M```````````````````````````!DR`````````````````````````````"
MP!(````````````````````````````!%A(`````````````````````````
M```#7!(``!8```````'W.``````````P````'1(``!8```````'X$```````
M``)D```#SB```!D```````(````````````````$=1(``!8```````'X*```
M``````",```#P1(``!8```````'X0`````````$X```$'1(``!8```````'W
MF`````````&X```#E!```!D```````(`@``````````````$#A$``!D`````
M``(`>``````````(```$-!```!H```````(`@``````````````#_A(``!8`
M``````'XH`````````"0```#;1(``!8```````'WR`````````!$```#M!(`
M`!8```````'X<`````````=@```$0!(``!8```````'V\`````````!<```$
M?A(``!8```````'XB`````````.X```#TA(``!8```````'UB``````````\
M```#3!(``!8```````'XN``````````0```#Z!(``!8```````'W(```````
M``#8```#B!(``!8```````'W^`````````"<```#S!```!D```````(`````
M```````````$2!(``!8```````'W4`````````(0```$&!```!H```````(0
MP``````````````#V1$```\```````!L$``````````$```$9Q(``!8`````
M``'WL`````````"$```$*A(``!8```````'X6`````````'````#FQ(``!8`
M``````'W:``````````T```#J!(``!8```````'W@`````````%<```$51(`
M`!8```````'WX`````````#@`%]?8WAA7V9I;F%L:7IE`%]?;&EB8U]S=&%R
M=%]M86EN`%]?<F5G:7-T97)?871F;W)K`%]?>'-T870V-`!?7VQX<W1A=#8T
M`%]?<W1A8VM?8VAK7V9A:6P`7U]E;G9I<F]N`'-T<FYC;7``86-C97-S`&]P
M96YD:7(`<F5A9&1I<C8T`&-L;W-E9&ER`')M9&ER`'-T<F-M<`!S=')L96X`
M7U]S<')I;G1F7V-H:P!U;FQI;FL`<F5A9&QI;FL`;65M8VAR`')E86QL;V,`
M;65M;6]V90!G971P:60`;65M8W!Y`'-T<F-H<@!S=')T;VL`<W1R9'5P`%]?
M<W1R;F-P>5]C:&L`9V5T=6ED`'-T<G-T<@!E>&ET`&UE;7-E=`!S=&1E<G(`
M;6MD:7(`7U]E<G)N;U]L;V-A=&EO;@!?7V9P<FEN=&9?8VAK`&]P96XV-`!L
M<V5E:S8T`')E860`8VQO<V4`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4$Q?
M9&]?=6YD=6UP`%!E<FQ?9W9?9F5T8VAP=@!097)L7V%V7W-H:69T`%!E<FQ?
M879?9F5T8V@`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?;&]C:P!097)L7W-V
M7S)P=E]F;&%G<P!097)L7V=E=%]S=@!097)L7VYE=UA3`&)O;W1?1'EN84QO
M861E<@!P97)L7W)U;@!P97)L7W!A<G-E`%!E<FQ?<W9?<V5T<'8`4&5R;%]S
M=E]S971P=FX`<&5R;%]C;VYS=')U8W0`<&5R;%]D97-T<G5C=`!P97)L7V%L
M;&]C`%!E<FQ?8W)O86M?;F]C;VYT97AT`'!E<FQ?9G)E90!097)L7W-A9F5S
M>7-M86QL;V,`4&5R;%]S>7-?:6YI=#,`4&5R;%]N97=84U]F;&%G<P!097)L
M7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?=&5R;0!03%]T:')?:V5Y`'!T:')E
M861?9V5T<W!E8VEF:6,`;&EB<&5R;"YS;P!L:6)P=&AR96%D+G-O+C``;&EB
M8RYS;RXV`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U
M<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!P87)?
M8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A=&4`
M7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`%]E;F0`<&%R7VEN:71?
M96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O
M9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C,`1TQ)0D-?,BXS+C0`1TQ)
M0D-?,BXS+C(`1TQ)0D-?,BXT`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#
M3U)%```````````"``(``@`"`````@`"``(``@```````@```````@`"``,`
M`````````@`````````"``0````"``4``@`"`````@`"`````@````(``@`"
M``(``@````,````"```````"``(````"``(````"``8````#`````@``````
M`@`"```````"``(``@`"`````@`"``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!```````!``$```,R````
M$````"`-:6D3````!0``!)0```````$`!````T(````0``````EI&70````&
M```$G@```!`):1ER````!```!*H````0#6EI%`````,```2V````$`UI:1,`
M```"```$E`````````````'S&``````````6```````!]A@```````'S(```
M```````6```````!]@````````'S,``````````6```````!^!````````'S
M.``````````6```````!^*````````'S0``````````6```````!^+@`````
M``'UB``````````6````````,B0```````'UD``````````6```````"?P``
M``````'UH``````````6````````)^````````'UJ``````````6```````"
M?P````````'UN``````````6````````:_0```````'UP``````````6````
M```"?P````````'UT``````````6````````,F````````'UV``````````6
M```````"?P````````'UZ``````````6````````,L````````'U\```````
M```6```````"?P````````'V```````````6````````,S````````'V"```
M```````6```````"?P````````'V&``````````6````````,Y````````'V
M(``````````6```````"?P````````'V,``````````6````````,Y0`````
M``'V.``````````6```````"?P````````'V2``````````6````````2/0`
M``````'V4``````````6```````"?P````````'V8``````````6````````
M2;P```````'V:``````````6```````"?P````````'V>``````````6````
M````2A0```````'V@``````````6```````"?P````````'VD``````````6
M````````2K````````'VF``````````6```````"?P````````'VJ```````
M```6````````2U````````'VL``````````6```````"?P````````'VP```
M```````6````````3-0```````'VR``````````6```````"?P````````'V
MV``````````6````````3=@```````'VX``````````6```````"?P``````
M``'V\``````````6````````3^@```````'V^``````````6```````"?P``
M``````'W"``````````6````````4$0```````'W$``````````6```````"
M?P````````'W(``````````6````````4+@```````'W*``````````6````
M```"?P````````'W.``````````6````````49````````'W0``````````6
M```````"?P````````'W4``````````6````````4<````````'W6```````
M```6```````"?P````````'W:``````````6````````4]````````'W<```
M```````6```````"?P````````'W@``````````6````````5`0```````'W
MB``````````6```````"?P````````'WF``````````6````````56``````
M``'WH``````````6```````"?P````````'WL``````````6````````5Q@`
M``````'WN``````````6```````"?P````````'WR``````````6````````
M5YP```````'WT``````````6```````"?P````````'WX``````````6````
M````5^````````'WZ``````````6```````"?P````````'W^``````````6
M````````6,````````'X```````````6```````"?P````````'X$```````
M```6````````+\````````'X&``````````6```````"?P````````'X*```
M```````6````````65P```````'X,``````````6```````"?P````````'X
M0``````````6````````6>@```````'X2``````````6```````"?P``````
M``'X6``````````6````````6R````````'X8``````````6```````"?P``
M``````'X<``````````6````````7.````````'X>``````````6```````"
M?P````````'XB``````````6````````9$````````'XD``````````6````
M```"?P````````'XH``````````6````````9_@```````'XJ``````````6
M```````"?P````````'XN``````````6````````:(@```````'XP```````
M```6```````"?P````````'XT``````````6````````:)@```````'XV```
M```````6```````"?P````````'XZ``````````6````````:-````````'X
M\``````````6```````"?P````````'Y```````````6````````:0P`````
M``'Y"``````````6```````"?P````````'_$``````````6```````!\R@`
M``````(`"``````````6```````"``@```````(`&``````````6````````
M;5P```````(`(``````````6````````;!4```````(`,``````````6````
M````;0$```````(`.``````````6````````;/H```````(`0``````````6
M````````;6$```````(`2``````````6````````;1<```````(`4```````
M```6````````;6D```````(`8``````````6````````;6T```````(`:```
M```````6````````;7(```````(`>``````````6````````;M@```````'_
M"````"4````F``````````````````'_&`````<````F````````````````
M``'_(````$D````F``````````````````'_*````"D````F````````````
M``````'_,````!X````F``````````````````'_.````!0````F````````
M``````````'_0`````T````F``````````````````'_2````#(````F````
M``````````````'_4````$`````F``````````````````'_6````!8````F
M``````````````````'_8````$4````F``````````````````'Y,`````,`
M```5``````````````````'Y2`````0````5``````````````````'Y8```
M``4````5``````````````````'Y>`````8````5``````````````````'Y
MD`````@````5``````````````````'YJ`````D````5````````````````
M``'YP`````H````5``````````````````'YV`````L````5````````````
M``````'Y\`````P````5``````````````````'Z"`````X````5````````
M``````````'Z(`````\````5``````````````````'Z.````!`````5````
M``````````````'Z4````!$````5``````````````````'Z:````!,````5
M``````````````````'Z@````!4````5``````````````````'ZF````!<`
M```5``````````````````'ZL````!@````5``````````````````'ZR```
M`!D````5``````````````````'ZX````!H````5``````````````````'Z
M^````!L````5``````````````````'[$````!P````5````````````````
M``'[*````!T````5``````````````````'[0````!\````5````````````
M``````'[6````"`````5``````````````````'[<````"$````5````````
M``````````'[B````"(````5``````````````````'[H````",````5````
M``````````````'[N````"0````5``````````````````'[T````"4````5
M``````````````````'[Z````"8````5``````````````````'\`````"<`
M```5``````````````````'\&````"@````5``````````````````'\,```
M`"D````5``````````````````'\2````"H````5``````````````````'\
M8````"P````5``````````````````'\>````"T````5````````````````
M``'\D````"X````5``````````````````'\J````"\````5````````````
M``````'\P````#`````5``````````````````'\V````#$````5````````
M``````````'\\````#,````5``````````````````']"````#0````5````
M``````````````'](````#4````5``````````````````'].````#8````5
M``````````````````']4````#<````5``````````````````']:````#@`
M```5``````````````````']@````#D````5``````````````````']F```
M`#H````5``````````````````']L````#L````5``````````````````']
MR````#P````5``````````````````']X````#T````5````````````````
M``']^````#X````5``````````````````'^$````#\````5````````````
M``````'^*````$$````5``````````````````'^0````$(````5````````
M``````````'^6````$,````5``````````````````'^<````$0````5````
M``````````````'^B````$8````5``````````````````'^H````$<````5
M``````````````````'^N````$@````5``````````````````'^T````$H`
M```5``````````````````'^Z````$L````5````````````````````````
M````````^$$`*#UB___IBWS0?8D#INA+?-A.@`0@``````````!\"`*F^`$`
M$/@A_Y%@````Z`*`""^@``!!_@`,2___Q>A!`"@X(0!PZ`$`$'P(`Z9.@``@
M````````````````^$$`*#UB___IBWW8?8D#INA+?>!.@`0@``````````#X
M00`H/6+__^F+?^A]B0.FZ$M_\$Z`!"```````````/A!`"@]8O__Z8M[L'V)
M`Z;H2WNX3H`$(```````````^$$`*#UB___IBWK8?8D#INA+>N!.@`0@````
M``````#X00`H/6+__^F+??!]B0.FZ$M]^$Z`!"```````````/A!`"@]8O__
MZ8M[('V)`Z;H2WLH3H`$(```````````^$$`*#UB___IBWLX?8D#INA+>T!.
M@`0@``````````#X00`H/6+__^F+?XA]B0.FZ$M_D$Z`!"```````````/A!
M`"@]8O__Z8M\*'V)`Z;H2WPP3H`$(```````````^$$`*#UB___IBW\H?8D#
MINA+?S!.@`0@``````````#X00`H/6+__^F+?<!]B0.FZ$M]R$Z`!"``````
M`````/A!`"@]8O__Z8MZ\'V)`Z;H2WKX3H`$(```````````^$$`*#UB___I
MBWU(?8D#INA+?5!.@`0@``````````#X00`H/6+__^F+?+A]B0.FZ$M\P$Z`
M!"```````````/A!`"@]8O__Z8M^L'V)`Z;H2WZX3H`$(```````````^$$`
M*#UB___IBWV0?8D#INA+?9A.@`0@``````````#X00`H/6+__^F+>U!]B0.F
MZ$M[6$Z`!"```````````/A!`"@]8O__Z8M\$'V)`Z;H2WP83H`$(```````
M````^$$`*#UB___IBWT`?8D#INA+?0A.@`0@``````````#X00`H/6+__^F+
M?(A]B0.FZ$M\D$Z`!"```````````/A!`"@]8O__Z8M\H'V)`Z;H2WRH3H`$
M(```````````^$$`*#UB___IBWYH?8D#INA+?G!.@`0@``````````#X00`H
M/6+__^F+?IA]B0.FZ$M^H$Z`!"```````````/A!`"@]8O__Z8M^@'V)`Z;H
M2WZ(3H`$(```````````^$$`*#UB___IBWJH?8D#INA+>K!.@`0@````````
M``#X00`H/6+__^F+?.A]B0.FZ$M\\$Z`!"```````````/A!`"@]8O__Z8M[
M:'V)`Z;H2WMP3H`$(```````````^$$`*#UB___IBWL(?8D#INA+>Q!.@`0@
M``````````#X00`H/6+__^F+>YA]B0.FZ$M[H$Z`!"```````````/A!`"@]
M8O__Z8M_$'V)`Z;H2W\83H`$(```````````^$$`*#UB___IBW[@?8D#INA+
M?NA.@`0@``````````#X00`H/6+__^F+?B!]B0.FZ$M^*$Z`!"``````````
M`/A!`"@]8O__Z8M[R'V)`Z;H2WO03H`$(```````````^$$`*#UB___IBWUX
M?8D#INA+?8!.@`0@``````````#X00`H/6+__^F+?UA]B0.FZ$M_8$Z`!"``
M`````````/A!`"@]8O__Z8M^4'V)`Z;H2WY83H`$(```````````^$$`*#UB
M___IBW_0?8D#INA+?]A.@`0@``````````#X00`H/6+__^F+?1A]B0.FZ$M]
M($Z`!"```````````/A!`"@]8O__Z8MZ>'V)`Z;H2WJ`3H`$(```````````
M^$$`*#UB___IBWOX?8D#INA+?`!.@`0@``````````#X00`H/6+__^F+?W!]
MB0.FZ$M_>$Z`!"```````````/A!`"@]8O__Z8M]8'V)`Z;H2WUH3H`$(```
M````````^$$`*#UB___IBWHP?8D#INA+>CA.@`0@``````````#X00`H/6+_
M_^F+>DA]B0.FZ$MZ4$Z`!"```````````/A!`"@]8O__Z8M\0'V)`Z;H2WQ(
M3H`$(```````````^$$`*#UB___IBWTP?8D#INA+?3A.@`0@``````````#X
M00`H/6+__^F+?[A]B0.FZ$M_P$Z`!"```````````/A!`"@]8O__Z8M^^'V)
M`Z;H2W\`3H`$(```````````^$$`*#UB___IBW^@?8D#INA+?ZA.@`0@````
M``````#X00`H/6+__^F+>^!]B0.FZ$M[Z$Z`!"```````````/A!`"@]8O__
MZ8M^R'V)`Z;H2W[03H`$(```````````^$$`*#UB___IBW]`?8D#INA+?TA.
M@`0@``````````#X00`H/6+__^F+>X!]B0.FZ$M[B$Z`!"```````````/A!
M`"@]8O__Z8M]J'V)`Z;H2WVP3H`$(```````````^$$`*#UB___IBWXX?8D#
MINA+?D!.@`0@``````````#X00`H/6+__^F+?@A]B0.FZ$M^$$Z`!"``````
M`````/A!`"@]8O__Z8MZD'V)`Z;H2WJ83H`$(```````````^$$`*#UB___I
MBWI@?8D#INA+>FA.@`0@``````````#X00`H/6+__^F+?%A]B0.FZ$M\8$Z`
M!"```````````/A!`"@]8O__Z8M\<'V)`Z;H2WQX3H`$(```````````^$$`
M*#UB___IBWK`?8D#INA+>LA.@`0@``````````!\"`*F^\'_\/OA__CX`0`0
M^"'_@?B!`+CXH0#`.($`N#BA`,"080"P.&$`L$O_^G7H00`H8````.BB@$A@
M````Z&*`4'RD*WA(`#B18````&````#I(H!8B\D``&````#KXH`X+!X``$""
M`$!+__X5Z$$`*&`````L(P``^&*1H$""`!`X8``!2__W^>A!`"A+__AQZ$$`
M*(!_``!+__U%Z$$`*)O#"[F`?P``2__]->A!`"B)(P8*82D``IDC!@J`?P``
M2__]'>A!`"B)(P8*82D``9DC!@J`80"P.&,`!7QC![1X8Q\D2__X>>A!`"CI
M`0"X8````&````#HH0"R?&8;>/ABD:CI*```+`4``/DC```](O_^.2GN3_DC
M``A@````.2*!>.DI``#Y(P`0/2+__CDI[E+Y(P`8.2``!)$BD;`Y)?__.4``
M`'DI`"`Y*0`!?2D#ID&!``PY(``!?2D#ICE*``%"``#4.*4``SE````\@O__
M..```'RE![0XA'@(>*D?)'U&22I@````Z&*1H$O_^(WH00`H?'\;>4""`!A@
M````Z&*1H$O_^[7H00`H?'\;>&````#H8I&@2__](>A!`"@\8O_^.&/MM$@`
M&"TL(P``0((`0&````#I(I&X+"D``$""`!@\8O_^.&/M:4@`&`E@````^&*1
MN&````#H8I&X+",``$&"``Q(`";Q8````&````#H8I&@2__W`>A!`"A+__H9
MZ$$`*#@A`(!_X_MX2``WQ'E)'R1\Z$@J.2H``WTI![1Y*1\D?.9)*DO__Q``
M`````````8`"``!\*0MX>"$&Y#@```#X(?^!?`@#IO@!``#I`H`02__]`&``
M``````````P@0``````````D``9?<W1A<G1@````8````#AB@8`Y(H&`?"D8
M`$V"`"!@````Z2*`&"PI``!-@@`@?`@"IO@!`!#X(?^1^$$`*.E)``#I:0`0
M?4D#INA)``A.@`0AZ$$`*#@A`'#H`0`0?`@#IDZ``"!@````8````#AB@8`X
M@H&`?(,@4'R$'G1\A`YT?(0!E4V"`"!@````Z2*`("PI``!-@@`@?`@"IO@!
M`!#X(?^1^$$`*.E)``#I:0`0?4D#INA)``A.@`0AZ$$`*#@A`'#H`0`0?`@#
MIDZ``"!@0@``8````(DB@8`L"0``3((`('P(`J9@````Z2*`*/@!`!#X(?^1
M+"D``$&"`!1@````Z&*!"$O_^EWH00`H2__^]3@A`'`Y(``!8````.@!`!"9
M(H&`?`@#IDZ``"!@0@``2___,'P(`J8Y0``(.0,`.'U)`Z9(`#6M^"'\L>DM
MC_#Y(0+X.2```#DA`'CI2```.2D`$#D(``AY1P`B>4H`(/CI__#Y2?_X0@#_
MY#D@`$`Y`0!P?2D#INDH`'#HZ`!(Z4@`&'TI.GA]*5)XZ4@`"7TI4GAY*@^D
M>2D/PGU)2WAY*0`@^2@`@$(`_]#H`P``Z*,`(.C#`!#I8P`(Z(,`&.CA`(!X
M"B[">`DNI'EH\()X'_!D?2E3>.E!`'A\W2)X/.=:@GDI`"!_O5@X..=YF3U*
M6H)_O2)X?.<B%#E*>9E]2BH4?2E2%'EJ\&1]2D-X?2GJ%'E(`"!Y.@`@>3XN
MR'DI+N)\W4)X?\E+>'^]`#A_O3)X?[TZ%'M'\&1_O4H4>`GP@G__2WCI(0"(
M>[L`('N\+LA[O2[B?5[Z>'OL`"#I00"8?YWK>#TI6H)_WM`X>UKP@CDI>9E_
MWD)X?.?3>#U*6H)]*3(4?_PZ>#E*>9E_WDH4Z2$`D'CZ`"!_G-@X?][J%'^<
M8GA]BF(4/2E:@GO8`"`Y*7F9>PKP9'T)0A1[:?!D>WOP@G^<0A1[R"[(?2G;
M>'O>+N)]'O-X?.A*>'D[`"!_G/(4?0C`.'L8\()[F0`@>YTNR'U*PWA[G"[B
M?0C2>'L_\&1_O.-X?3U2>.DA`*!]"&(4>4P`('^]R#A[.?""?0CB%#TI6H)_
MO=IX>1P`('D>+L@Y*7F9>0@NXG__RWA[A_!D?TG2%.DA`*A_R$-X?5[Z>.E!
M`+A_O=(4>_H`('_>X#A[G/""/2E:@G^]0A1\Y^-X?]YB>#DI>9E[J``@?_PZ
M>#U*6H)_:=H4>ZDNR'N]+N)_G$`X?][:%#E*>9E]/>MXZ2$`L'^<TGA_2M(4
M>/L`('_>ZA0]*5J">]T`(#DI>9E]B6(4>\DNR'O>+N)_G&(4?3[S>'D)\&1Y
M"/""?YSR%'TI0WA[G@`@>XHNR'SH2GA[G"[B>2P`('O?\&1]7.-X?0CH.'NJ
M\&1[O?""?0C:>'U*ZWA]"-(4?3U2>.DA`,!Y6@`@?0CB%'^]\#A[WO"">1P`
M(#TI6H)___-X?[UB>'N'\&0Y*7F9?5[Z>.E!`-A_:=H4>0DNR'D(+N)_WN`X
M?[W:%'N<\()]*$-XZ2$`R'_>TGA\Y^-X>_L`('^]0A0]2EJ">/P`(#TI6H)[
MJ``@.4IYF3DI>9E]B6(4Z2$`T'_>8A1[K"[(>[TNXCTI6H)]G>MX?^PZ>#DI
M>9E_WNH4?8Q`.'])TA1[W0`@>\DNR'V,VGA[WB[B?VK:%'T^\WA]C-(4>0GP
M9'D(\()]C/(4?2E#>'F>`"!YBB[(?.A*>'F,+N)Y.@`@>]_P9'U,8WA]".@X
M>ZKP9'N]\()]".)X?4KK>'T(VA1]/5)XZ2$`X'E;`"!]"&(4?[WP.'O>\()Y
M#``@/2E:@G^]TGA___-X>8?P9#DI>9E]7OIXZ4$`^'^)XA1Y"2[(>0@NXG_>
M8#A_O>(4>8SP@GTH0WCI(0#H?][:>'SG8WA[_``@?[U"%#U*6H)_[#IX/2E:
M@GNY`"`Y2GF9.2EYF7V,R#A[*/!D>SGP@G])TA1[J2[(>[TNXGT(RWA_WM(4
M?8SB>'T]ZWCI(0#P?XKB%'D?`"!_WNH4>/T`(#TI6H)[V@`@.2EYF7]IVA1[
MR2[(>]XNXGV,VA1]/O-X?.E">'M'\&1]C/(4?2G0..O!`2A[6O"">9L`('F*
M+LA\Y]-X>8PNXGTIZG@_WF[:?4QC>'T*.GCI`0$`?2GB%'C\`"!]2M@X.][K
MH7TI8A0]"%J"?4KZ>'DY`"`Y"'F9?ZCJ%'DH+LAY*2[B?4KJ%'T)2WCI`0$(
M?4I*%'MI\&1[>_""/0A:@GE=`"!]*=MX>SOP9#D(>9E\YTIX>3H`('_H^A1Y
M2"[B?.?(.'LY\()Y2B@H?WO+>'SGXGA]2D-X?2C:>.DA`1!\Y_H4Z^$!,'U'
M4A1]".@X/2E:@GE'+N)]"-)X/_]NVCDI>9D[_^NA?XGB%'E)*"A]".(4?2D[
M>'N\\&1[O?""?0A*%.DA`1A_G.MX>0<H*']]XGA[>P`@/2ENVG^]4G@Y*>NA
M>[T`('TITA1Y6O"(>4KPHG^]2A1Y"2[B?UI3>'SG2WCI(0$@?XK2>'N<`"!_
MO3H4?4I">'_>XA0]*6[:>Z<NXGE*`"`Y*>NA?2G:%'TI4A1[JB@H?4H[>'U)
M4A1Y"?"(>0CPHGE'+N)Y7/"(?2A#>'])0GA[6@`@?2GJ>'__TA1Y*0`@?]Y*
M%'E)*"A]*3MX>Z?PB'N]\*)_WDH4?/WK>'O'+N)]">IX>0@`('TI4GAY2O"B
M>2D`('^<4WA__TH4>\DH*'^JXGA[O0`@?2D[>.CA`4!]2O)X?_]*%.DA`3AY
M2@`@/.=NVGO[\(@]*6[:..?KH3DIZZ%\Y^H4?2E"%'OH+N)]*5(4>^HH*'U*
M0WA[R/"(>][PHGTI4A1]'O-X>2@NXG^*\GA[G``@?4KZ>'O_\*)Y2@`@?WO[
M>'SG4A1Y*B@H?4I#>'_(VGA[W@`@?.=2%.E!`4A]"$IX>0@`('C_+N)X_?"(
M/4INVCE*ZZ%]2N(4>3SPB'DI\*)]2D(4>.@H*'^<2WA]"/MX?VGB>'M[`"!]
M2D(4Z0$!4'TI.GAXY_"B>5\NXGDI`"!_O3MX/0ANVCD(ZZ%]"/(4>5[PB'T(
M2A1Y22@H?2G[>.OA`5A]"$H4?XGJ>'N<`"`__V[:?2E2>'D'+N)Y2O"B.__K
MH7DI`"!_WE-X?__:%'^J\GA[O0`@?_]*%'D)*"A]2D)X?2D[>'E*`"!__TH4
MZ2$!8'OG+N(]*6[:.2GKH7TIXA1Y'/"(>0CPHGTI4A1[ZB@H?YQ#>'U*.WCH
MX0%H?2E2%'_*XGA[W@`@/.=NVGU*^GAY*"[B..?KH7E*`"!\Y^H4>_WPB'O_
M\*)\YU(4>2HH*'^]^WA]2D-X?XCJ>'N<`"!\YU(4Z4$!<'T(2GAX_R[B>0@`
M(#U*;MHY2NNA?4KR%'D^\(AY*?"B?4I"%'CH*"A_WDMX?0C[>'^I\GA[O0`@
M?4I"%.D!`7A]*3IX>5\NXGDI`"`]"&[:.0CKH7T(XA1X_/"(>.?PHGT(2A1Y
M22@H?YP[>'TI^WCKX0&`?0A*%'_)XGA[W@`@/_]NVGTI4GAY!R[B.__KH7DI
M`"!__^H4>5WPB'E*\*)__TH4>0DH*'^]4WA]*3MX?XKJ>'N<`"!__TH4Z2$!
MB'U*0GA[YR[B>_OPB'E*`"`]*6[:.2GKH7TI\A1Y'O"(>0CPHGTI4A1[ZB@H
M?]Y#>'U*.WCHX0&0?2E2%'^J\GA[O0`@/.=NVGU*^GAY*"[B>__PHCCGZZ%Y
M2@`@?WO[>'SGXA1Y//"(?.=2%'DJ*"A]2D-X?\C:>'O>`"!\YU(4Z4$!F'T(
M2GAY*?"B>0@`('^<2W@]2F[:.4KKH7U*ZA1X_2@H?4I"%'CH+N)_O4-X?ZKJ
M%.E!`:![J2@H/0INVG]JXGA[>P`@?4HZ>#D(ZZ%Y2@`@?0CR%'C^\(AXY_"B
M?0A2%'NJ+N)_QSMX>[[PB'TI4WCI00&H?0A*%'^).GA[G``@/^INVGTIZGAY
M"B[B>[WPHCO_ZZ%Y*0`@?]WK>'__VA1[K``@?_]*%'D)+LA]*5-XZ4$!L'__
M2A0]*F[:?.KJ>'OY`"!XYP`@?4I">#DIZZ%Y2@`@?2GB%'L\\&1]*5(4>^HN
MR'O_+N)]7_MX>0KPB'D(\*)]*?H4Z^$!N'U(0W@]0(\;>3L`(&%*O-QY&@`@
M?[Y#>'E*`"!_O=`X?][(.'LY\()_ZOH4?][K>'^<RWA\_SH4>W_P9'N9`"!_
MWCH4>2<NR'DI+N)\Z4MX?0?C>'^(T#A\Y]@X?3Y*%'M[\()\YT-XZ0$!P'DV
M`"!__]MX>MOP9'^=^WA]"D(4?[VP.'K6\()]B&(4>2@NR'DI+N)_>[-X?.=B
M%'OL`"!]"4MXZ0$!T'^<8#A\YTH4Z2$!R'^]XWAX]P`@?0I"%'TJ2A1_*,H4
M?TG2%'CI+LAXYR[B?[W2%'MZ`"!])SMX?^G;>']_8#A\_3H4?2FX.'CX`"!X
MZ"[(?2G[>'CG+N)['/!D?0<[>'TIRA1ZZ/!D>O?P@GTI.A3HX0'8?0B[>'DV
M`"!_?D-X>1D`('SJ.A1ZW_!D?][`.'L8\()]AV(4>2<NR'^<PWAY*2[B?WO(
M.'SI2WA]!^-X?XC(.'_>VWA\Y[`X>M;P@G_>8A1[C``@?.=#>.D!`>!__[-X
M?3Y*%'^=^WAY-P`@?0I"%'^]N#AZ^_!D?TC2%'DH+LAY*2[B>O?P@GSGTA1[
M^@`@?0E+>'][NWCI`0'P?YS0.'SG2A3I(0'H?[WC>'CX`"!]"D(4?2I*%'V(
M8A1_*<H4>.DNR'CG+N)_O<H4>WD`('TG.WA_Z=MX?W_0.'S].A1]*<`X>/8`
M('CH+LA]*?MX>.<NXGK<\&1]!SMX?2EB%'L(\&1[&/""?2DZ%.CA`?A]",-X
M>3<`(']^0WAY#``@?.HZ%'K_\&1_WK`X>M;P@G]'TA1Y)R[(?YRS>'DI+N)_
M>V`X?.E+>'T'XWA_B&`X?][;>'SGN#AZ]_""?][2%'N:`"!\YT-XZ0$"`'__
MNWA]/DH4?YW[>'DX`"!]"D(4?[W`.'L;\&1_*,H4>2@NR'DI+N)[&/""?.?*
M%'OY`"!]"4MX?WO#>.D!`A!_G,@X?.=*%.DA`@A_O>-X>/8`('T*0A1]*DH4
M?TC2%'V)8A1XZ2[(>.<NXG^]8A1[;``@?2<[>'_IVWA_?\@X?/TZ%'TIL#AX
M]P`@>.@NR'TI^WAXYR[B>OSP9'T'.WA]*=(4>LCP9'K6\()]*3H4Z.$"&'T(
MLWAY.``@?WY#>'D:`"!\ZCH4>Q_P9'_>N#AZ]_""?R?*%'DG+LA_G+MX>2DN
MXG][T#A\Z4MX?0?C>'^(T#A_WMMX?.?`.'L8\()_WLH4>YD`('SG0WCI`0(@
M?__#>'T^2A1[^P`@?YW[>'DV`"!]"D(4?YS8.'^]L#A]B&(4>2@NR'DI+N)_
MO>-X?.=B%'T)2WCI`0(P?.=*%.DA`BAX]P`@?0I"%'TJ2A1_*,H4?TG2%'CI
M+LAXYR[B?[W2%'TG.WA\_3H4>MWP9'K6\()X^``@>.@NR'^]LWAXYR[B?^GK
M>'^_V#A]!SMX>NCP9'TIN#AZ]_"">[H`('TI^WA]"+MX?2G*%'D<`"!_OD-X
M?2DZ%.CA`CA_O>`X?][`.'DL`"!_WNMX?.HZ%'F?\&1_9]H4>2<NR'DI+N)_
MWMH4?.E+>'T^2A1['O!D>QCP@GDY`"!_WL-X?0?S>'_(X#A[VP`@?.=@.'F,
M\()\YT-XZ0$"0'__8WA_W?MX?0I"%'^]R#A_2-(4>2@NR'DI+N)\Y](4>_H`
M('T)2WA_WM`X?.=*%.DA`DA_OO-X>.@`('TJ2A1_B>(4>.DNXGCG*"A_WN(4
M?.=+>'LI\&1[.?""?/XZ%'TIRWAX_/"(?_]+>'T]T#AY/@`@?_]`.'__ZWCK
MH0)0?4KJ%'C]+N)]2MH4>1OP9'D(\()]7U(4>/\H*'][0WA__^MX?2C:>#T@
MRF)]2OH4Z^$"6&$IP=9]"#IX>5TNXGCG\*)Y*0`@>0@`('^'.WA_Z?H4?U_2
M%'E?*"A]"-(4?__K>']].GA[>P`@?0CZ%.OA`F!_O5)X>[T`('_I^A1_W_(4
M>1\H*'^]\A1Y'B[B?__S>'E>\(AY2O"B?[WZ%.OA`FA_RE-X>[PNXGS^4GAX
MYP`@?^GZ%'_>0GA__]H4>]X`('__\A1[OB@H?][C>.N!`G!___(4>1[PB'D(
M\*)_B>(4>_OPB'_(0WA[_B[B?YPZ%'U'0GAY2@`@?.?J>'CG`"!_G#H4>^<H
M*'SG\WCKP0)X?YPZ%'NG\(A[O?"B?\GR%'S]ZWA[AR[B?]Y2%'T*ZGAY"``@
M?4KZ>'O_\*)Y2@`@?WO[>'_>4A1[BB@H?4H[>.CA`H!_WE(4?ZK:>'N]`"!\
MZ3H4?4KB>'SG0A1Y2@`@>\@NXGSG4A1[RB@H?4I#>'N(\(A[G/"B?.=2%'T<
MXWCI`0*(>/\NXG]JXGA[>P`@?0E"%'U*\GA]".H4>4H`('O=\(A[WO"B?0A2
M%'CJ*"A_O?-X?4K[>.OA`I!]"%(4?XKJ>'N<`"!_Z?H4?4HZ>'D>+N)__]H4
M>4H`('C[\(AXY_"B?_]2%'D**"A_>SMX?4KS>'^GVGA[O0`@?_]2%.E!`IA\
MYT)X>_XNXGCG`"!]25(4?4KB%'D<\(AY"/"B?4HZ%'OG*"A_G$-X?.?S>.O!
M`J!_:.)X>WL`('U*.A1]"/IX?\GR%'E'+N)Y"``@?][J%'O]\(A[__"B?]Y"
M%'E(*"A_O?MX?0@[>.CA`JA_WD(4?XCJ>'N<`"!\Z3H4?0A2>'O?+N)\Y]H4
M>0@`('E;\(AY2O"B?.="%'O(*"A_>U-X?0C[>'^JVGA[O0`@?.="%.D!`K!]
M2O)X>/\NXGE*`"!]"4(4?0CB%'O<\(A[WO"B?0A2%'CJ*"A_G/-X?4K[>.OA
M`KA]"%(4?VKB>'M[`"!_Z?H4?4HZ>'D>+N)__^H4>4H`('C]\(AXY_"B?_]2
M%'D**"A_O3MX?4KS>'^'ZGA[G``@?_]2%.E!`L!\YT)X>_XNXGCG`"!]25(4
M?4K:%'D;\(AY"/"B?4HZ%'OG*"A_>T-X?.?S>.O!`LA_J-IX>[T`('U*.A1]
M"/IX?\GR%'E'+N)Y"``@?][B%'O\\(A[__"B?]Y"%'E(*"A_G/MX?0@[>.CA
M`M!_WD(4?VCB>'M[`"!\Z3H4?0A2>'O?+N)\Y^H4>0@`('E=\(AY2O"B?.="
M%'O(*"A_O5-X?0C[>'^*ZGA[G``@?.="%.D!`MA]2O)X>/\NXGE*`"!]"4(4
M?0C:%'T(4A1XZB@H?4K[>.OA`N!]"%(4>\KPB'O>\*)_Z?H4?5[S>'__XA1Y
M'"[B?ZKR>'N]`"!]2CIX>4H`('__4A1Y"B@H?4KC>'__4A1XZO"(>.?PHGO\
M+N)]1SMXZ4$"Z'RG*A1]25(4>*4`('U*ZA1_W3IX^*,`('O>`"!_O4)X>[T`
M('U*ZA1[_2[(?[WC>'U*ZA1Y'?"(>0CPHG^H0WCKH0+P?2GJ%'TI`A1\X$)X
M?0@B%'P`^GA]*?(4>5XNXGD(`"!X```@^0,`&'TI`A1Y0"[(?4I:%'P`\WAY
M2@`@?2D"%/E#``AY*0`@^2,``'OI\(A[__"B?2G[>'S),A1XQ@`@^,,`$.DA
M`OCI38_P?2E2>3E```!!@@`,2__BB>A!`"@X(0-02``@I``````````!@`H`
M`'P(`J9(`"!I?'P;>?@A_V$[P```08(`)&`````[P```?)HC>'^%XWCI(H`P
MZZD``"P]``!`@@`<."$`H'_#\WA(`"!D*`D`/4&"`!0XI0`!B24``"PI``!`
M@O_L?+PH4'^[ZWA\OP>TZ]L``"P^``!!@O_(?^7[>'^$XWA_P_-X2__CC>A!
M`"@L(P``0((`*'T^^*XL"0`]0((`''^]V%`[_P`!?[T>='_>^A23N@``2___
MB#M[``A+__^P``````````&`!@``?`@"IO@!`!#X(?^!.($`=.DMC_#Y(0!X
M.2```$O__QWI(0!XZ4V/\'TI4GDY0```08(`#$O_X7'H00`H."$`@.@!`!!\
M"`.F3H``(``````````!@````'P(`J;[P?_P^^'_^'Q_&WCX`0`0^"'_<>DM
MC_#Y(0!X.2```#O!`'1_Q/-X?^/[>$O__K$L(P``0((`(.DA`'CI38_P?2E2
M>3E```!!@@`\2__@_>A!`"CI(0!V>2D?)#E)__A@````Z2*`,.DI``!]*5(4
MZ4D`$"PJ``#Y20`)0(+_]$O__Z0X(0"02``?'``````````!@`(``'P(`J;[
MX?_X?'\;>/@!`!#X(?[A.($`>.DMC_#Y(0$(.2```$@`'CE@````+",``$""
M`%2!(0"052D$)B@)0`!!@@`0;2K__RP*H`!`@@`<.(```G_C^WA+_^!YZ$$`
M*'QC`#148]E^Z2$!".E-C_!]*5)Y.4```$&"`!1+_^`UZ$$`*#A@``!+___@
M."$!($@`'H```````````8`!``!\"`*F2``>!?@A_K%\?AMYZ2V/\/DA`0@Y
M(```08(`:(D^```L"0``08(`7$O_W\7H00`H?'P;>4&"`$P_8O_^/T+__C\B
M__X[`0!X.WOM%3M:[10[.>T7?X/C>$O_W_7H00`H?'\;>4""`#A_@^-X2__>
MX>A!`"A_P_-X2__B->A!`"CI(0$(Z4V/\'TI4GDY0```08(`W$O_WWGH00`H
M._\`$W]DVWA_X_MX2__=I>A!`"@L(P``08+_H']$TWA_X_MX2__=C>A!`"@L
M(P``08+_B'_#\WA+_^%9Z$$`*'Q]&WA_X_MX2__A2>A!`"A\?1H4.&,``GQC
M![1+_^!5Z$$`*'_H^WA_Q_-X?'T;>'\FRW@XH/__.(```4O_W97H00`H?P3#
M>'^CZWA(`!Q58````"P#__]_H^MX08(`*($A`)!5*00F+`E``$""`!A+__ZQ
M?Z/K>$O_W]GH00`H2__^^$O_W(WH00`H2___Z#@A`5!(`!S,``````````&`
M"```?`@"ICB@#_](`!R)^"'O47Q_&W@\8O_^?)TC>#AC[1T[@0!XZ2V/\/DA
M$'@Y(```?X3C>$O_X1GH00`H8````"P#``#K8H`X0($`B'Q^![0Y01"`.3[_
M_WTI![1]2DH4B4KO^"P*``!`@@`0+"D``$&"`&!]/DMX?\7S>#B``"]_@^-X
M2__B2>A!`"@L(P``08(`0(![``!+_^`UZ$$`*'_&\WA_A>-X?^3[>$O_WN'H
M00`HZ2$0>.E-C_!]*5)Y.4```$&"`"Q+_]W%Z$$`*(![``!+_]_YZ$$`*'^E
MZWA_Y/MX2__:J>A!`"A+___(."$0L$@`&]0``````````8`%``!\"`*F2``;
M@?@A_T%\?QMX?)XC>.DMC_#Y(0!X.2```(DD```L"0`]0((`"#O$``%_P_-X
M2__?=>A!`"@X@0!T?'T;>'_C^WA+__K5?'P;>4&"`$A+_]]5Z$$`*'P]&$!!
M@0"T.2```'U>2*XL*@``?5Q)KCDI``%`@O_PZ2$`>.E-C_!]*5)Y.4```$&"
M`7!+_]SYZ$$`*&````#K8H`P.2```.L[```Y&?_X?3P'M#DI``%Y*A\D?4A0
M*BPJ``!`@O_L8````#B<``*!(H&0?(0'M'B$'R0L"0``08(`X'\CRWA+_]_%
MZ$$`*"PC``#X>P``08+_B#D\``'I6P``.0```'TI![1Y*1\D?0I)*I.!`'1_
MZ?MXB4D``"PJ``!!@@`,*`H`/4""`,Q@````?3](4#A]``+K8H`P?2D'M.N!
M`'9\8TH4ZUL``$O_W7WH00`H+",``'N<'R1\>N$J08+_'.DA`';I6P``.___
M_WDI'R1]*D@JC5\``7TH2W@Y*0`!+"H``)E)__]!@@`,*`H`/4""_^0Y0``]
MF4@``#E```!]'E"N+"@``'T)4:XY2@`!0(+_\$O__L0Y(``!8````'R#(WB1
M(H&02__<_>A!`"A\>AMY08+^I'N%'R1_),MX2__?)>A!`"C[6P``2___"#DI
M``%+__\@."$`P$@`&;P``````````8`'``!\"`*F8````.DB@#CX`0`0^"'_
MD8!I``!+_]VAZ$$`*&`````\PO_^/(+__NBB@$`XQBI`.(3M+$O_V`'H00`H
M."$`<.@!`!!\"`.F3H``(``````````!@````'P(`J;[X?_X8````.OB@#CX
M`0`0^"'_@8!_``!+_]U!Z$$`*$O__X%@````@'\``$O_W2WH00`H/2+__SSB
M__X\@O_^.0```#CG[]<XJ7F(.(3M2'SF.WA+_]M%Z$$`*#@A`(!(`!D8````
M``````&``0``?`@"ID@`&+'X(=]1Z2V/\/DA((@Y(```.^$0@$O_V"WH00`H
M/0+__CS"__Y\9QMX.0CM*#C&[5TXH!`!.(```7_C^W@[H0!X2__9`>A!`"A_
MX_MX.*`0`'^DZW@[X```2__=">A!`"@L`P``08``.'Q^![0X?@`!?&,'M$O_
MVVWH00`H?'\;>4&"`!Q_Q?-X?Z3K>$O_V;7H00`H.2```'T_\:[I(2"(Z4V/
M\'TI4GDY0```08(`#$O_V?'H00`H."$@L'_C^WA(`!@D``````````&``P``
M?`@"IO@!`!#X(?^12___'6`````X(0!PZ`$`$'P(`Z9.@``@``````````&`
M````?8``)GP(`J9(`!>!D8$`"/@A[I%\?AMX/&+__GR?(W@X8^UIZ2V/\/DA
M$0@Y(```2__WS3B``"]\>QMX?\/S>$O_VV'H00`H+",``$&"`#`\8O_^?\3S
M>#AC[7)+__N]Z2$1".E-C_!]*5)Y.4```$&"`8!+_]DMZ$$`*'_#\W@_0O_^
M/R+__C[B__Y+_]LUZ$$`*#M:[7\^PO_^?'T'M'_C^WA_1--X.H```"X[```[
M.>T52__7K>A!`"@[````.[T``7Q_&W@Z]^V!.M;N@CN!`0@ZH0!X8I2``"P_
M``!!@O]PB3\``"P)``!`@@`(?S_+>$&2`"!_Y/MX?V/;>$O_UN'H00`H?T33
M>"PC``!!@@#0?^/[>$O_VJGH00`H?&D'M#E)__]]2@>T?1]0KBP(`"]!@@"8
M?3U*%"P)#_]!@?\0?\GS>'[HNWA_Y_MX?L:S>#B@$``X@``!?X/C>$O_UN'H
M00`H?J2K>'^#XWA(`!6A8````"PC``!`@@!<@2$`D%4I!"9\":``0((`3#B`
M``%_@^-X2__8*>A!`"@L(P``0((`-#QB__Y_A.-X.&/M<DO_^F5_@^-X2__;
MA>A!`"A\?AMX2__^F'\?4:Y]25-X2___4']$TW@X8```2__6@>A!`"A\?QMX
M2__^\#@A$7!_P_-X@8$`"'V0@2!(`!7```````````.`#```?&D;>'TC2WA(
M```0*`H`+SDI``%!@O_PB4D``"PJ``!`@O_L3H``(````````````````'P(
M`J;[X?_X?'\;>?@!`!#X(?^!08(`$(D_```L"0``0((`$#QB__XX8^T52``!
M%$O_V4WH00`H?&D#ICDC__]\?QH4.&/__WR_2A1\/QA`08$`#"P___]`@@`,
M.2```7TI`Z9"0`#`B24``"P)`"]!@@"D?#\H0'T_*%`Y*0`!?2D#ID"!``PY
M(``!?2D#ID)``)2))0``.47__RP)`"]`@@!\.47__WT_*%!\/U!`08$`#"P_
M__]`@@`(.2```2PI``$XI?__.2G__T&"`!")10``+`H`+T&"_^A\ORA0.&``
M`#DE``(H*1``08$`7&`````XP!``.*4``7_D^W@Y(H&@?2-+>$O_U=7H00`H
M2```.#BE__]+__],?453>$O__W!\/RA`0(+_?(D_```\8O_^.&/M@2P)`"]!
M@O[H2__9O>A!`"@X(0"`2``4<``````````!@`$``'P(`J8\8O_^.&/M@T@`
M$_WX(?]!/\+__C^B__X[WNVD/^+__CN][6D_@O_^.__MP#N<[<KI+8_P^2$`
MF#D@```](O_^.2DJ2NC)``#HZ0`(Z0D`$.E)`!BA*0`@^,$`</CA`'CY`0"`
M^4$`B+$A`)!+__1%/&+__CAC[8Q+__0Y/&+__CAC[91+__0M/&+__CAC[9U+
M__0A?\/S>$O_]!D\8O_^.&/MM$O_]`U_H^MX2__T!7_C^WA+__/]?X/C>$O_
M\_4\8O_^.&/MU$O_\^D\8O_^.&/M<DO_\]T\8O_^.&/MWDO_\WE\9!MY08(`
M#'^#XWA+__>%/&+__CAC[>]+__-=?&0;>4&"`!`\8O_^.&/N`4O_]V4\8O_^
M.&/N#$O_\SU\9!MY08(`.'^CZWA+__=)/(+__G_#\W@XA.XX2__W.>DA`)CI
M38_P?2E2>3E```!!@@!02__4J>A!`"@\8O_^.&/N'$O_\O5\9!MY08(`#'_C
M^WA+__^X/(+__CB@``HX80"!.(3N+4O_UA7H00`H+",``$""_YPX@0"+2___
MU#@A`,!(`!*8``````````&`!```8````($B@1`L"?__0((`8'P(`J8\8O_^
M.&/MP/@!`!#X(?^12__R@3E````L(P``08(`'(DC```L*0``08(`$&DI`#`Q
M2?__?4I)$&`````X(0!PD4*!$.@!`!!@````?`@#INAB@1).@``@8````.AB
M@1).@``@``````````&`````?`@"IO@!`!#X(?^12__0^>A!`"A+_]61Z$$`
M*"PC``!!@@`(Z&,``#@A`'#H`0`0?`@#IDZ``"```````````8````!\"`*F
M2``1A?@A_W$_@O_^?'\;>#N<[CI_@^-X2__QP7_D^WA\?AMY08(`$(D^```L
M"0``0((`*#@A`)!_@^-XZ`$`$.N!_^#KH?_HZ\'_\.OA__A\"`.F2__UH$O_
MU(7H00`H+",``$""`&1_X_MX2__5,>A!`"A\?1MX?\/S>$O_U2'H00`H?'T:
M%#AC``)+_]0QZ$$`*#T"__X\PO_^?'T;>#B```%_R?-X.0CM?W_G^W@XQNZ"
M.*#__TO_T67H00`H?Z3K>$O__W`X(0"02``0\``````````!@`0``'P(`J;[
MP?_P^^'_^'Q_&WCX`0`0^"'_@4O_^RU@````2__Z\6````!\?AMX2__^+6``
M```L(P``08(`4"P_``!!@@!(B3\``"P)``!!@@`\/(+__G_#\W@XA.Y*2__3
MI>A!`"A\/A@`0((`(#@A`(!_X_MXZ`$`$.O!__#KX?_X?`@#IDO_\@PX(0"`
M2``0<``````````!@`(``'P(`J8X8`"`^`$`$/@A_Y%+_],UZ$$`*#U`9T4X
M(0!P84HC`?E#```]0._-84JKB7E*`"#Y0P`(/4"8NF%*W/YY2@`@^4,`$#U`
M$#)A2E1V^4,`&#U`P])A2N'P>4H`(/E#`"`Y0```D4,`>/E#`"CY0P`PZ`$`
M$'P(`Z9.@``@``````````&`````?`@"IGBI'R1(``]Q^"'_87Q^&WA\GR-X
M?+TK>.E#`"A]*5(4>2D`('PJ2$!`@0`0Z4,`,#E*``'Y0P`PZ'X`>OD^`"CI
M/@`P>ZH?0CN>`#A]*5(4+",``/D^`#!!@@!8(2,`0'^[ZWA\'4@`0($`"'T[
M2WA_>@>T?^3[>'Q\&A1_1=-X2__0E>A!`"B!/@!X?2G:%"P)`$"1/@!X0((`
M.'^[Z%!__](4?[T'M'_#\WA+_]C]+!T`/T&!`"1_I>MX?^3[>'^#XWA+_]!1
MZ$$`*).^`'@X(0"@2``.V.C_``#I'P`(.[W_P#O_`$#I7__0Z3__V'^]![3X
M_```^1P`"/E<`!#Y/``8Z/__X.D?_^CI7__PZ3__^/C\`"#Y'``H^5P`,/D\
M`#A+__^$``````````&`!@``?`@"ICE`_X!(``X]^"'_83MD`#A\?AMX?)\C
M>.ND`"CKA``P5Z7NOGNI[J(XI0`!?5M)KBP%`#A\HP>T?'L:%$"!`60@I0!`
M.(```'RE![1+_\T1Z$$`*'_C^WA+_]@9.*``.#B```!_8]MX2__,]>A!`"A[
MB48"FY\`<YN_`'>9/P!P>XF$`G_C^WB9/P!Q>XG"`ID_`')[J48"F3\`='NI
MA`*9/P!U>ZG"`ID_`'9+_]?%Z3\``'_C^WAY*48"F3X``.D_``!Y*80"F3X`
M`>D_``!Y*<("F3X``ND_``"9/@`#Z3\`"'DI1@*9/@`$Z3\`"'DIA`*9/@`%
MZ3\`"'DIP@*9/@`&Z3\`")D^``?I/P`0>2E&`ID^``CI/P`0>2F$`ID^``GI
M/P`0>2G"`ID^``KI/P`0F3X`"^D_`!AY*48"F3X`#.D_`!AY*80"F3X`#>D_
M`!AY*<("F3X`#ND_`!B9/@`/Z3\`('DI1@*9/@`0Z3\`('DIA`*9/@`1Z3\`
M('DIP@*9/@`2Z3\`()D^`!-+_\_-Z$$`*#@A`*!(``S<(*4`.#B```!\I0>T
M2__^O``````````!@`4``'P(`J8Y(```82F!N$@`#&D\`/__/T+__GQ[&WA@
M`'WP.UKM:7PA`6I_0]-X?2D*%#OA@<#I38_P^4D``#E```!@````Z2*!&/D_
M?VA@````Z2*!(/D_?W!@````Z2*!*/D_?WA@````Z2*!,/D_?[!@````Z2*!
M./D_?[A@````Z2*!0/D_?\!@````Z2*!2/D_?\A@````Z2*!4/D_?]!@````
MZ2*!6/D_?]A@````Z2*!8/D_?U!@````Z2*!:/D_?UA@````Z2*!</D_?V!+
M_^P-?'X;>4&"`%")/@``+`D``$&"`$1+__H98````'_#\WA+_]$MZ$$`*'Q^
M&W@Y(```82F!N'TI"A3I20``Z2V/\'U*2GDY(```08(&+$O_S6'H00`H2__Y
ME6`````[OW](?'X;>4&"`9Q_P_-X/X+__CO>__]+_\]9Z$$`*#N<[GMX8P^D
M.&,``4O_SF7H00`H?'D;>'Q]&WB,_@`!+"<``$""`7@[OW^HZ]T`"2P^``!!
M@@`\?\/S>$O_ZU%\?AMY08+_Z(D^```L"0``08+_W$O_["TL(P``08+_T'_#
M\WA+_]!MZ$$`*'Q^&W@[GW]@+#X``$""`!SKO``)+#T``$&"`5R)/0``+`D`
M`$""`2Q_P_-X/N+__DO_SK7H00`H.O?M@7Q\&WA_(\MX2__.H>A!`"A_G!H4
M.YP$!'^<![1_@^-X2__-J>A!`"@](O_^/,+__GQ]&WA_*LMX.2GN2G[HNWA_
MQ_-X.,;N@#B@__\X@``!2__*V>A!`"@X@`'`?Z/K>$O_R^GH00`H+`/__T""
M`-1+_\_9Z$$`*.D#``(L"``108(`P&`````\HO_^Z-L``'^GZW@X@``!Z2*`
M8#BE[HGH:0``2__.Y>A!`"@[P```2__^6$O_ZC%\:1MY08(`((DI```L"0``
M08(`%$O_SUWH00`H?'X;>4""_FSH?0`)+",``$""_]`_PO_^.][N54O__E1_
MH^MX?X;C>#B@__\X@``!.[T``DO_RB'H00`H2__^9'^CZWA+_^K!+",``$&"
M_K1_H^MX2__/`>A!`"A\?AMX2__^F#O```!+__ZP.)]^P'^CZWA(``CM8```
M`'QX&WE!@@`P8````#RB__[HVP``?Z?K>#B```'I(H!@.*7NQ.AI``!+_\X1
MZ$$`*$O__RR!/W[852D$)BP)0`!`@O_(@]]^W$O_R#'H00`H?#X8`$""_[2!
M/W[852D%_BP)`<!`@O^D?X/C>$O_S`WH00`H?'X;>#QB__XX8^Y%2__I%2PC
M``!`@@&XZSL``'\CRWA+_\S%Z$$`*"P#``-\?`>T0($`A#A\__P\@O_^?'D:
M%#B$[Q=+_\C!Z$$`*"PC``!`@@!D+!P`!$&"`!@[G/_[?YP'M'TYX*XL"0`O
M0((`2.N;``@L/```08(`/'^#XWA+_\QEZ$$`*"@C``-`@0`H.&/__#R"__Y\
M?!H4.(3O'$O_R&7H00`H+",``$""``A_F>-X2__UR6`````L(P``0((""#B`
M``!_(\MX2__+>>A!`"A\?!MY08(!\#B@``(X@/_N.W]_^$O_S%WH00`H.*``
M!G]DVWA_@^-X2__'R>A!`"B)/W_X+`D``$""`.B)/W_Y+`D`0T""`-R)/W_Z
M+`D`04""`-")/W_[+`D`0T""`,2)/W_\+`D`2$""`+B)/W_]+`D`14""`*PX
MH``".(#_QG^#XWA+_\OMZ$$`*#B@`"E_9-MX?X/C>$O_QUGH00`H/4+__G]I
MVW@Y2N_7/,+__G[HNWA_I^MX.*#__SC&[R$X@``!?\/S>$O_Q\GH00`H?Z/K
M>$O_RCWH00`H?T/3>'_$\WA+_^N%?\/S>$O_]85@````2__[?.N;``!+_\R5
MZ$$`*'QD&WA_@^-X2__O16````!\>1MY0(+^,$O__B@XH```.(```'^#XW@[
M`/__.S]_^$O_RSWH00`H5Q@$($O_]JU@````?'L;>'\%PWA_),MX?X/C>$O_
MQIGH00`H+`,``'QE![1!@0!X?X/C>#N??^`_`O_^.S]_@$O_QM7H00`H?V3;
M>'^#XW@[8```.QCN>TO_^!U@````?/S8KG\CRWA_!L-X.*#__SB```$[>P`!
M.SD``DO_QMGH00`H*#L`%$""_]@Y(```/4+__ID_?Z@Y2N_7.3]_@$O__M!_
M),MX?V/;>$O_]I%@````2___7#R"__X\8O_^/^+__C^"__XXA.XX.&/MP#O_
M[]<[G.\^2__J54O_Q7GH00`H/,+__G_J^WA\:1MX?NB[>'^GZW@XQN\P.*#_
M_SB```%_P_-X2__&3>A!`"@X@`'`?\/S>$O_QUWH00`H+`/__T""_G!+_\M-
MZ$$`*($C```L"0`10(+^7$O_Q1GH00`H^^$`<#L8``%^Z+MX?&D;>'\8![1_
MI^MX?X;C>#B@__]_"L-X.(```7_#\WA+_\7EZ$$`*$O__YCH(0``?\/S>$@`
M!5P``````````8`)``!\"`*F8````$@`!1'X(?]1Z^*`.(!_``!+_\E)Z$$`
M*'Q^&WB`?P``2__).>A!`"B)/@"XF2,`N3QB__XX8^VD2__E/2PC``!!@@`<
MB2,``"P)`#%`@@`0B2,``2P)``!!@@`,2__PO6````"`?P``8````#N"@9!+
M_\CIZ$$`*#R"__XXP``+.*```3B$[T]+_\6QZ$$`*"PC``!`@@$X@'\``$O_
MR+WH00`H/(+__CC```,XH``!.(3O5$O_Q87H00`H?'X;>4""`A2`?P``2__(
MD>A!`"@\@O_^.,```SB@``$XA.]T2__%6>A!`"A\?AMY08(`.#QB__XX8^UR
M2__D?7Q]&WF`?P``08("*$O_R%'H00`HZ3X`$'^EZWCHB0``2__"_>A!`"B`
M?P``2__(,>A!`"A\?AMX@'\``$O_R"'H00`H/(+__CB@``$XA.];2__&K>A!
M`"@\HO_^?&0;>'_#\W@XI>]P2__"M>A!`"B`?P``2__'Z>A!`"@Y(```F2,`
MN3QB__XX8^UI2__C[6`````L(P``^&*1N$""`;A@````Z&*1J$O_]O5@````
M8````"PC``#X8I&X0((!F#QB__XX8^]V2__(M>A!`"CI(P`0/R``(#O```%C
M.00`ZTD`*($\$"`[?O__@'\``'][![1\"?``0($`*$O_QV'H00`H.,```']E
MVWA_1--X2__%;>A!`"A\?1MY0((`(&````"!(I&P.2G__WP)V`!`@OYL.\``
M`4@``(SI7!`8>\D?)'\*2"KI70``@2H`#'\I2#@L"00`0((`*.B*`!!_`\-X
M2__"^>A!`"@L(P``0(+_L#O>``%_W@>T2___:(!_``!+_\;9Z$$`*.B=```X
MP``".*```$O_Q47H00`H?&0;>$O__[Q+_\:UZ$$`*#O>``%_1--X?]X'M$O_
MPH'H00`H@3P0((!_``!\"?``08'_V$O__<B`?P``2__&@>A!`"CI/@`0/*+_
M_CBE[U;HB0``2__!*>A!`"CI/@`0Z2D``($I``QU*0!`08+]O(!_``!+_\9)
MZ$$`*.D^`!#HB0``2__#6>A!`"A+__V<2__&+>A!`"A@````Z3X`$.E"D:CH
M:0``Z(H``$O_Y45+__W88````#B``<#KXI&X?^/[>$O_PWGH00`H+`,`$7QF
M&WA!@@`L.2,``2@)``%`@0`@Z3P0&#QB__Y_Y?MX.&/OE^B)``!+_\;EZ$$`
M*#@A`+!(``&H``````````&`"```?`@"ID@``67X(?]A/T+__S_B__\[6G08
M?'T;>#O_="!\G"-X?+LK>#O```!_^OA0?_\>=$O_O[5@````?#[X0$""``PX
M(0"@2``!6/A!`"A[R1\D?V7;>'^$XWA].D@J?Z/K>#O>``'I20``Z6D`$'U)
M`Z;H20`(3H`$(>A!`"A+__^\``````````&`!@``3H``(```````````````
M`'P(`J9@````Z,*!"/@!`!#X(?^12__!E>A!`"@X(0!PZ`$`$'P(`Z9.@``@
M``````````&`````?`@"IGR%(WA\9!MX.&```?@!`!#X(?^12__&>>A!`"@X
M(0!PZ`$`$'P(`Z9.@``@``````````&`````?`@"IGR%(WA\9!MX.&```?@!
M`!#X(?^12__&7>A!`"@X(0!PZ`$`$'P(`Z9.@``@``````````&`````^H'_
MH/JA_ZCZP?^P^N'_N/L!_\#[(?_(^T'_T/MA_]C[@?_@^Z'_Z/O!__#[X?_X
M^`$`$$Z``"#J@?^@ZJ'_J.K!_[#JX?^XZP'_P.LA_\CK0?_0ZV'_V.N!_^#H
M`0`0ZZ'_Z'P(`Z;KP?_PZ^'_^$Z``"#KP?_PZ`$`$.OA__A\"`.F3H``(```
M`````8\X?8@"ID*?``5]:`*FZ$O_\'V(`Z9]8EH4Z8L``.A+``A]B0.FZ6L`
M$$Z`!"`X````2___T#@```%+___(.````DO__\`X```#2___N#@```1+__^P
M.```!4O__Z@X```&2___H#@```=+__^8.```"$O__Y`X```)2___B#@```I+
M__^`.```"TO__W@X```,2___<#@```U+__]H.```#DO__V`X```/2___6#@`
M`!!+__]0.```$4O__T@X```22___0#@``!-+__\X.```%$O__S`X```52___
M*#@``!9+__\@.```%TO__Q@X```82___$#@``!E+__\(.```&DO__P`X```;
M2__^^#@``!Q+__[P.```'4O__N@X```>2__^X#@``!]+__[8.```($O__M`X
M```A2__^R#@``")+__[`.```(TO__K@X```D2__^L#@``"5+__ZH.```)DO_
M_J`X```G2__^F#@``"A+__Z0.```*4O__H@X```J2__^@#@``"M+__YX.```
M+$O__G`X```M2__^:#@``"Y+__Y@.```+TO__E@X```P2__^4#@``#%+__Y(
M.```,DO__D`X```S2__^.#@``#1+__XP.```-4O__B@X```V2__^(#@``#=+
M__X8.```.$O__A`X```Y2__^"#@``#I+__X`.```.TO__?@X```\2__]\#@`
M`#U+__WH?`@"IO@!`!#X(?^1."$`<.@!`!!\"`.F3H``(``"``$N+@`E<R\E
M<P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`+P!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)
M3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$
M14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-
M4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)97U!!5$@`<&%R+0`M90`M+0!3
M65-414T`+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`)7,E
M<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E<R5S=&5M
M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'5@`8`'!E<FP`4$%2.CI086-K
M97(Z.E9%4E-)3TX`,2XP-3``56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E
M8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@!E=F%L("=E>&5C("]U<W(O8FEN
M+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U
M;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!
M1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I
M9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A
M<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL
M93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M
M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N
M86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L
M;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF
M:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H
M*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*)%!!4E]-04=)
M0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I
M('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@
M)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*
M?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*
M=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&2"P@)&UA9VEC7W!O
M<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D
M4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@)&UA9VEC7W!O<R`\
M(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B
M=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L
M("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@
M)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO
M861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN="`D
M9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@[
M"GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&EN9F\M/GMC
M<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I
M;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN
M;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F
M86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I
M;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B
M4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL
M;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G
M/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A
M7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@)69I;&5S
M*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>
M0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD["FQA<W0[
M"GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["FEF
M("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS:68@*"UF
M("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q
M*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M92!A;F0@
M;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I;B`B(BP*
M<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F
M:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P96X@1DE,
M12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*
M8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E($9)3$4[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M
M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N
M86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H
M0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D[
M"GT*;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B
M1DE,12(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DI.PHD9F@M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT
M*"1C;VYT96YT*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@
M:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L
M(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D
M;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["F]P
M96XH;7D@)&9H+"`B/"(L("1O=70I.PIB:6YM;V1E*"1F:"D["B1C='@M/F%D
M9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!
M1TE#*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I
M.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T
M=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER
M92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R
M97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U
M:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@
M<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D
M<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!4
M14U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2![
M"FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M
M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U
M:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I
M;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R
M.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R
M;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T52
M3D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@
M/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE
M(#T@*'-T870H)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N
M("1P<F]G;F%M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M
M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L
M("TU."P@,CL*<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O
M+V<["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U
M9CL*?0IE;'-E('L*;7D@)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;BAM
M>2`D9F@L("(\(BP@)'!R;V=N86UE*3L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S=#L*?2!\
M?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TD
M9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!
M3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"([
M"GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F
M:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D
M9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L
M;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@
M;7D@)&9H+"`G/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T
M96UP;F%M93H@)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I
M+F,`7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("````$;`SL```$(
M````(/__AE0```30__^**````3C__Y^(```!?/__H%````&T__^@J````=3_
M_Z%$```!_/__H>0```(D__^C:````F#__Z1L```"E/__IGP```+0__^FV```
M`O#__Z=,```#&/__J"0```-$__^H5````V3__ZID```#M/__JI@```/(__^K
M]````_#__ZVL```$(/__KC````1`__^N=```!&#__Z]4```$G/__K_````3X
M__^P?```!1C__[&T```%4/__LW0```6(__^ZU```!<S__[Z,```&"/__OQP`
M``9`__^_+```!E3__[]D```&=/__OZ````:4___`;````2`````0``````%Z
M4@`$>$$!&PP!`````!0````8__^_1````AP`0@E!#$0&00```$`````P__^(
MZ```%6``1`E!`$&6"I<)F`B9!YH&FP6<!)T#G@*?`1%!?D$.T`8#!4X.`$'?
MWMW<V]K9V-?6!D$`````-````'3__YX$````R`!!"4$`09H&FP6<!)T#G@*?
M`1%!?D(.H`%+"@X`0M_>W=S;V@9!"P`````<````K/__GI0```!8`$,.@`$1
M07Y-#@!"!D$``````"0```#,__^>S````)P`0PE!`)X"GP%##I`!$4%^70X`
M0=_>!D$````D````]/__GT````"@`$()00"?`4,.H`(107Y?#@!!WP9!````
M````.````1S__Y^X```!A`!!"4$`09@(F0>:!IL%G`2=`YX"GP$107Y!#M`"
M`EH.`$'?WMW<V]K9V`9!````,````5C__Z$````!!`!""4$`09L%G`2=`YX"
MGP$107Y!#K`A>0X`0=_>W=S;!D$``````#@```&,__^AT````A``00E!`$&9
M!YH&FP6<!)T#G@*?`1%!?D$.P`$"?0X`0=_>W=S;VMD&00```````!P```'(
M__^CI````%P`10YP$4%^3`X`0@9!````````)````>C__Z/@````=`!#"4$`
MGP%##H`!$4%^4PX`0=\&00```````"@```(0__^D+````-@`00E!`$&=`YX"
MGP$107Y!#K!!;@X`0M_>W09!````'````CS__Z38````,`!##G`107Y##@!"
M!D$```````!,```"7/__I.@```(0`$()00!!E`R5"Y8*EPF8")D'F@:;!9P$
MG0.>`I\!$4%^0@[P(A%&?P)X#@!$W][=W-O:V=C7UM74!D$&1@```````!``
M``*L__^FJ````#0`````````)````L#__Z;(```!7`!""4$`GP%##H`!$4%^
M`DX.`$'?!D$``````"P```+H__^G_````;@`0PE!`$&<!)T#G@*?`1%!?D$.
MP`$"90X`0=_>W=P&00```!P```,8__^IA````(0`20YP$4%^3`X`1`9!````
M````'````SC__ZGH````1`!##G`107Y(#@!"!D$````````X```#6/__J@P`
M``#@`$$)00!!G`2=`YX"GP$107Y!#I`!3`H.`$<&0=_>W=Q!"UT.`$'?WMW<
M!D$````P```#E/__JK````"<`$,)00">`I\!0PZ``1%!?E8*#@!%!D'?WD$+
M00X`0=_>!D$`````)````\C__X%\```"9`!%#H`!$4%^G@*?`0*("@X`0M_>
M!D$+`````!P```/P__^J\````(P`1`YP$4%^1`X`5P9!````````-```!!#_
M_ZM<```!.`!""4$`09H&FP6<!)T#G@*?`1%!?D$.H`%R"@X`0=_>W=S;V@9!
M"P`````T```$2/__K%P```'``$()00!!FP6<!)T#G@*?`1%!?D$.H`$"9`H.
M`$'?WMW<VP9!"P```````$````2`__^MY```!V``0PE!`$&7"9@(F0>:!IL%
MG`2=`YX"GP$107Y&#I"$`@,!R0X`0M_>W=S;VMG8UP9!````````.```!,3_
M_[4````#N`!""4$`09@(F0>:!IL%G`2=`YX"GP$107Y!#K`!`N8.`$'?WMW<
MV]K9V`9!````-```!0#__[A\````D`!!"4$`09H&FP6<!)T#G@*?`1%!?D$.
MH`%/"@X`0=_>W=S;V@9!"P`````0```%./__N-0````0`````````!P```5,
M__^XT````#@`10YP$4%^0PX`0@9!````````'```!6S__[CH````/`!&#G`1
M07Y##@!"!D$````````<```%C/__N00````\`$8.<!%!?D,.`$(&00``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```!]A@```````'V```````````````````!^!````````'XH````````?BX
M``````````$````````#)P`````````!`````````S(``````````0``````
M``-"``````````\````````$P``````````,```````!]:``````````#0``
M`````?6X`````````!D```````'S&``````````;``````````@`````````
M&@```````?,@`````````!P`````````"``````````$`````````E@`````
M;__^]0````````<```````````4````````2```````````&````````"%@`
M````````"@````````3>``````````L`````````&``````````5````````
M`````````````P```````?D8``````````(````````%T``````````4````
M``````<`````````%P```````"'@`````'````````````!IY``````````'
M````````&"``````````"`````````G```````````D`````````&```````
M```8````````````````;___^P`````(```!`````&____X````````7L```
M``!O____``````````(`````;___\````````!;>`````&____D`````````
M70``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````,B0`
M``````)_````````````````````)^````````)_````````````````````
M:_0```````)_````````````````````,F````````)_````````````````
M````,L````````)_````````````````````,S````````)_````````````
M````````,Y````````)_````````````````````,Y0```````)_````````
M````````````2/0```````)_````````````````````2;P```````)_````
M````````````````2A0```````)_````````````````````2K````````)_
M````````````````````2U````````)_````````````````````3-0`````
M``)_````````````````````3=@```````)_````````````````````3^@`
M``````)_````````````````````4$0```````)_````````````````````
M4+@```````)_````````````````````49````````)_````````````````
M````4<````````)_````````````````````4]````````)_````````````
M````````5`0```````)_````````````````````56````````)_````````
M````````````5Q@```````)_````````````````````5YP```````)_````
M````````````````5^````````)_````````````````````6,````````)_
M````````````````````+\````````)_````````````````````65P`````
M``)_````````````````````6>@```````)_````````````````````6R``
M``````)_````````````````````7.````````)_````````````````````
M9$````````)_````````````````````9_@```````)_````````````````
M````:(@```````)_````````````````````:)@```````)_````````````
M````````:-````````)_````````````````````:0P```````)_````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````"?P``````````
M`````````?,H````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````"``C_____````````````
M`&U<````````;!4``````````````````&T!````````;/H```````!M80``
M`````&T7````````;6D``````````````````&UM````````;7(`````````
M`````````&[81T-#.B`H1TY5*2`Q,"XS+C$@,C`R,3`U,3`@*$%/4T,@3U,L
M($-O<F4I```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`
M+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N
M=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI
M;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A
M;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L+G)O`"YD>6YA
M;6EC`"YO<&0`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT````````````````
M````````````````````````````````````````````````````````````
M````````````````"P````$``````````@````````(``````````@``````
M````$0````````````````````$``````````````!,````'``````````(`
M```````"%`````````(4`````````"0````````````````````$````````
M```````F````!P`````````"`````````C@````````".``````````@````
M````````````````!```````````````.`````4``````````@````````)8
M`````````E@````````$J`````8```````````````@`````````!````#1O
M___V``````````(````````'``````````<``````````50````&````````
M```````(```````````````^````"P`````````"````````"%@````````(
M6`````````FH````!P````,`````````"``````````8````1@````,`````
M`````@```````!(`````````$@`````````$W@````````````````````$`
M`````````````$YO____``````````(````````6W@```````!;>````````
M`,X````&```````````````"``````````(```!;;____@`````````"````
M````%[`````````7L`````````!P````!P````(`````````"```````````
M````:@````0``````````@```````!@@````````&"`````````)P`````8`
M``````````````@`````````&````'0````$`````````$(````````AX```
M`````"'@````````!=`````&````%P`````````(`````````!@```!^````
M`0`````````&````````)\`````````GP`````````!4````````````````
M````(```````````````A`````$`````````!@```````"@@````````*"``
M``````!#U````````````````````"```````````````(H````!````````
M``8```````!K]````````&OT`````````!P````````````````````$````
M``````````"0`````0`````````"````````;!````````!L$````````#U<
M````````````````````"```````````````F`````$``````````@``````
M`*EL````````J6P````````!#`````````````````````0`````````````
M`*8````!``````````(```````"J>````````*IX````````!:P`````````
M```````````$``````````````"P````#@`````````#```````!\Q@`````
M``#S&``````````(````````````````````"``````````(````O`````\`
M`````````P```````?,@````````\R``````````"```````````````````
M``@`````````"````,@````!``````````,```````'S*````````/,H````
M`````"`````````````````````(``````````````#5````!@`````````#
M```````!\T@```````#S2`````````)`````!P``````````````"```````
M```0````W@````$``````````P```````?6(````````]8@````````#D```
M``````````````````@``````````````'D````(``````````,```````'Y
M&````````/D8````````!>@````````````````````(`````````!@```#C
M`````0`````````#```````!_P````````#_``````````!H````````````
M```````!```````````(````Z`````$``````````P```````@`````````!
M````````````@`````````````````````@``````````````.X````(````
M``````,```````(`@````````0"`````````$$`````````````````````0
M``````````````#S`````0`````````P``````````````````$`@```````
M```K`````````````````````0`````````!`````0````,`````````````
M```````````````!`*L`````````_`````````````````````$`````````
!````
